==> jec-glasscat-core-0.1.1.tgz: package/src/com/onsoft/glasscat/security/session/GlassCatSession.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.


import {Session, SessionId, SessionOwner} from "jec-exchange";

/**
 * The <code>GlassCatSession</code> class is the default implementation of the
 * <code>Session</code> interface for Glasscat containers.
 */
export class GlassCatSession implements Session {

  //////////////////////////////////////////////////////////////////////////////
  // Constructor function
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Initializes this <code>GlassCatSession</code> instance.
   */
  constructor() {}

  //////////////////////////////////////////////////////////////////////////////
  // Public properties
  //////////////////////////////////////////////////////////////////////////////

  /**
   * The session identifier.
   */
  public sessionId:SessionId = null;

  /**
   * Contains information about the owner of this session.
   */
  public sessionOwner:SessionOwner = null;

  /**
   * The expiration time for this session, in milliseconds.
   */
  public expires:number = 0;

  /**
   * The session data.
   */
  public data:any = null;
}

==> jec-glasscat-core-0.1.8.tgz: package/src/com/onsoft/glasscat/security/session/GlassCatSession.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2018 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.


import {Session, SessionId, SessionOwner} from "jec-exchange";

/**
 * The <code>GlassCatSession</code> class is the default implementation of the
 * <code>Session</code> interface for GlassCat containers.
 */
export class GlassCatSession implements Session {

  //////////////////////////////////////////////////////////////////////////////
  // Constructor function
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Initializes this <code>GlassCatSession</code> instance.
   */
  constructor() {}

  //////////////////////////////////////////////////////////////////////////////
  // Public properties
  //////////////////////////////////////////////////////////////////////////////

  /**
   * The session identifier.
   */
  public sessionId:SessionId = null;

  /**
   * Contains information about the owner of this session.
   */
  public sessionOwner:SessionOwner = null;

  /**
   * The expiration time for this session, in milliseconds.
   */
  public expires:number = 0;

  /**
   * The session data.
   */
  public data:any = null;
}
